@@ -288,7 +288,7 @@ gst_frame_positioner_update_properties (GstFramePositioner * pos,
   reposition_properties (pos, old_track_width, old_track_height);
 
 done:
-  GST_DEBUG_OBJECT (caps, "setting caps");
+  GST_DEBUG_OBJECT (pos, "setting caps %" GST_PTR_FORMAT, caps);
 
   g_object_set (pos->capsfilter, "caps", caps, NULL);
 
@@ -624,7 +624,7 @@ gst_frame_positioner_get_property (GObject * object, guint property_id,
 GType
 gst_frame_positioner_meta_api_get_type (void)
 {
-  static volatile GType type;
+  static GType type;
   static const gchar *tags[] = { "video", NULL };
 
   if (g_once_init_enter (&type)) {
